CHANGELOG
=========

### upcoming

- nothing currently planned

### 1.0.1

- updated dependencies

### 1.0.0

- formatted code using [black](https://pypi.org/project/black/)

### 0.0.1

- initial version of `apolitical-data-viz`
